@@ -2,11 +2,6 @@
 
 package machine
 
-import (
-	"device/sam"
-	"runtime/interrupt"
-)
-
 // used to reset into bootloader
 const RESET_MAGIC_VALUE = 0xf01669ef
 
@@ -60,18 +55,7 @@ const (
 )
 
 // UART1 on the QT Py M0.
-var (
-	UART1  = &_UART1
-	_UART1 = UART{
-		Buffer: NewRingBuffer(),
-		Bus:    sam.SERCOM0_USART,
-		SERCOM: 0,
-	}
-)
-
-func init() {
-	UART1.Interrupt = interrupt.New(sam.IRQ_SERCOM0, _UART1.handleInterrupt)
-}
+var UART1 = &sercomUSART0
 
 // SPI pins
 const (
@@ -81,12 +65,7 @@ const (
 )
 
 // SPI on the QT Py M0.
-var (
-	SPI0 = SPI{
-		Bus:    sam.SERCOM0_SPI,
-		SERCOM: 0,
-	}
-)
+var SPI0 = sercomSPIM0
 
 // I2C pins
 const (
@@ -96,10 +75,7 @@ const (
 
 // I2C on the QT Py M0.
 var (
-	I2C0 = &I2C{
-		Bus:    sam.SERCOM1_I2CM,
-		SERCOM: 1,
-	}
+	I2C0 = sercomI2CM1
 )
 
 // I2S pins
